OidcUserInfoResponse class

Annotations
  • @JsonSerializable.new(createFactory: true, createToJson: false, constructor: '_', converters: OidcInternalUtilities.commonConverters)

Constructors

OidcUserInfoResponse.fromJson(Map<String, dynamic> src)
Parses OidcUserInfoResponse from json object.
factory

Properties

aud List<String>
final
claimNames Map<String, String>?
JSON object whose member names are the Claim Names for the Aggregated and Distributed Claims.
final
claimSources Map<String, OidcClaimSource>?
JSON object whose member names are referenced by the member values of the _claim_names member. The member values contain sets of Aggregated Claims or reference locations for Distributed Claims.
final
exp DateTime?
The "exp" (expiration time) claim identifies the expiration time on or after which the JWT MUST NOT be accepted for processing.
final
hashCode int
The hash code for this object.
no setterinherited
iat DateTime?
The "iat" (issued at) claim identifies the time at which the JWT was issued.
final
iss String?
The "iss" (issuer) claim identifies the principal that issued the JWT.
final
jti String?
The "jti" (JWT ID) claim provides a unique identifier for the JWT.
final
nbf DateTime?
The "nbf" (not before) claim identifies the time before which the JWT MUST NOT be accepted for processing.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
src Map<String, dynamic>
The source json object.
finalinherited
sub String?
The "sub" (subject) claim identifies the principal that is the subject of the JWT.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](String key) → dynamic
gets a value from the src json
inherited